@@ -25,8 +25,14 @@ function restoreSettings() {
     else {
         Controller.setMediaPlayer(Settings.getSetting("mediaPlayer"));
     }
-    YouTube.setPlaybackQuality(Settings.getSetting("playbackQuality"));
-    DownloadManager.setDownloadQuality(Settings.getSetting("downloadQuality"));
+    var downloadQuality = Settings.getSetting("downloadQuality");
+    if (downloadQuality == "mobile") {
+        Settings.setSetting("downloadQuality", "hq");
+        DownloadManager.setDownloadQuality("hq");
+    }
+    else {
+        DownloadManager.setDownloadQuality(downloadQuality);
+    }
     Sharing.setFacebookToken(Settings.getAccessToken("Facebook"));
     var twitterToken = Settings.getAccessToken("Twitter");
     if (!(twitterToken == "unknown")) {
